@@ -8,8 +8,8 @@ import re
 class StringUtil(object):
     """Methods in this class are all static methods. Deal with strings."""
 
-    first_cap_pattern = re.compile('(.)([A-Z][a-z]+)')
-    all_cap_pattern = re.compile('([a-z0-9])([A-Z])')
+    first_cap_pattern = re.compile(ur'(.)([A-Z][a-z]+)')
+    all_cap_pattern = re.compile(ur'([a-z0-9])([A-Z])')
     @staticmethod
     def camelcase_to_underscore(name):
         """Convert CamelCase to camel_case"""
